==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ThirdPartyAdminSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The third-party admin setting
 */
@ApiModel(description = "The third-party admin setting")
@JsonPropertyOrder({ ThirdPartyAdminSetting.JSON_PROPERTY_THIRD_PARTY_ADMIN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class ThirdPartyAdminSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_THIRD_PARTY_ADMIN = "thirdPartyAdmin";
    private Boolean thirdPartyAdmin;

    public ThirdPartyAdminSetting() {
    }

    public ThirdPartyAdminSetting thirdPartyAdmin(Boolean thirdPartyAdmin) {

        this.thirdPartyAdmin = thirdPartyAdmin;
        return this;
    }

    /**
     * Indicates if third-party admin is enabled
     *
     * @return thirdPartyAdmin
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "false", value = "Indicates if third-party admin is enabled")
    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getThirdPartyAdmin() {
        return thirdPartyAdmin;
    }

    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setThirdPartyAdmin(Boolean thirdPartyAdmin) {
        this.thirdPartyAdmin = thirdPartyAdmin;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ThirdPartyAdminSetting thirdPartyAdminSetting = (ThirdPartyAdminSetting) o;
        return Objects.equals(this.thirdPartyAdmin, thirdPartyAdminSetting.thirdPartyAdmin);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(thirdPartyAdmin);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ThirdPartyAdminSetting {\n");
        sb.append("    thirdPartyAdmin: ").append(toIndentedString(thirdPartyAdmin)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ThirdPartyAdminSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The third-party admin setting
 */
@ApiModel(description = "The third-party admin setting")
@JsonPropertyOrder({ ThirdPartyAdminSetting.JSON_PROPERTY_THIRD_PARTY_ADMIN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ThirdPartyAdminSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_THIRD_PARTY_ADMIN = "thirdPartyAdmin";
    private Boolean thirdPartyAdmin;

    public ThirdPartyAdminSetting() {
    }

    public ThirdPartyAdminSetting thirdPartyAdmin(Boolean thirdPartyAdmin) {

        this.thirdPartyAdmin = thirdPartyAdmin;
        return this;
    }

    /**
     * Indicates if third-party admin is enabled
     *
     * @return thirdPartyAdmin
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "false", value = "Indicates if third-party admin is enabled")
    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getThirdPartyAdmin() {
        return thirdPartyAdmin;
    }

    @JsonProperty(JSON_PROPERTY_THIRD_PARTY_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setThirdPartyAdmin(Boolean thirdPartyAdmin) {
        this.thirdPartyAdmin = thirdPartyAdmin;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ThirdPartyAdminSetting thirdPartyAdminSetting = (ThirdPartyAdminSetting) o;
        return Objects.equals(this.thirdPartyAdmin, thirdPartyAdminSetting.thirdPartyAdmin);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(thirdPartyAdmin);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ThirdPartyAdminSetting {\n");
        sb.append("    thirdPartyAdmin: ").append(toIndentedString(thirdPartyAdmin)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
